@@ -13,6 +13,7 @@ import org.gcube.portlets.user.td.resourceswidget.client.store.ZoomLevelElement;
 import org.gcube.portlets.user.td.resourceswidget.client.store.ZoomLevelStore;
 import org.gcube.portlets.user.td.resourceswidget.client.store.ZoomLevelType;
 import org.gcube.portlets.user.td.resourceswidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
@@ -79,8 +80,9 @@ public class ChartViewerPanel extends FramedPanel {
 	private static final int IMAGE_HEIGHT = 768;
 	// private static final String RETRIEVE_CHART_FILE_SERVLET =
 	// "RetrieveChartFileServlet";
-	//private static final String RETRIEVE_FILE_AND_DISCOVER_MIME_TYPE_SERVLET = "RetrieveFileAndDiscoverMimeTypeServlet";
-	//private static final String ATTRIBUTE_STORAGE_URI = "storageURI";
+	// private static final String RETRIEVE_FILE_AND_DISCOVER_MIME_TYPE_SERVLET
+	// = "RetrieveFileAndDiscoverMimeTypeServlet";
+	// private static final String ATTRIBUTE_STORAGE_URI = "storageURI";
 
 	private static final String WIDTH = "810px";
 	private static final String HEIGHT = "440px";
@@ -134,6 +136,8 @@ public class ChartViewerPanel extends FramedPanel {
 	private Vector2D chartTranslation;
 	private ComboBox<ZoomLevelElement> comboZoomLevel;
 	private TextButton btnOpenInWindow;
+	private ChartViewerMessages msgs;
+	private CommonMessages msgsCommon;
 
 	public ChartViewerPanel(ChartViewerDialog parent,
 			ResourceTDDescriptor resourceTDDescriptor, TRId trId,
@@ -145,6 +149,7 @@ public class ChartViewerPanel extends FramedPanel {
 			ResourceTDDescriptor resourceTDDescriptor, TRId trId,
 			EventBus eventBus, boolean test) {
 		super();
+		initMessages();
 		ResourceBundle.INSTANCE.resourceCSS().ensureInjected();
 		this.eventBus = eventBus;
 		this.parent = parent;
@@ -161,6 +166,11 @@ public class ChartViewerPanel extends FramedPanel {
 
 	}
 
+	protected void initMessages() {
+		msgs = GWT.create(ChartViewerMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
+
 	public static String encodeUrlDelimiters(String s) {
 		if (s == null) {
 			return null;
@@ -184,8 +194,8 @@ public class ChartViewerPanel extends FramedPanel {
 		if (resource instanceof InternalURITD) {
 			internalURITD = (InternalURITD) resource;
 		} else {
-			UtilsGXT3.alert("Attention",
-					"This resource does not have valid internal URI!");
+			UtilsGXT3.alert(msgsCommon.attention(),
+					msgs.errorInvalidInternalURI());
 			Log.debug("Attention, this resource does not have valid Internal URI!");
 			close();
 			return;
@@ -196,47 +206,59 @@ public class ChartViewerPanel extends FramedPanel {
 	}
 
 	protected void retrieveUrlFromResolver() {
-		String name=resourceTDDescriptor.getName();
-		MimeTypeSupport mts=MimeTypeSupport.getMimeTypeSupportFromMimeName(internalURITD.getMimeType());
-		if(mts!=null){
-			name=name+mts.getExtension();
-		} 
-	
-	
-		UriResolverSession uriResolverSession = new UriResolverSession(
-				internalURITD.getId(), ApplicationType.SMP_ID,
-				name, internalURITD.getMimeType());
-		Log.debug("UriResolverSession: "+uriResolverSession);
-		TDGWTServiceAsync.INSTANCE.getUriFromResolver(uriResolverSession,
-				new AsyncCallback<String>() {
+		String name = resourceTDDescriptor.getName();
+		MimeTypeSupport mts = MimeTypeSupport
+				.getMimeTypeSupportFromMimeName(internalURITD.getMimeType());
+		if (mts != null) {
+			name = name + mts.getExtension();
+		}
 
-					public void onFailure(Throwable caught) {
-						if (caught instanceof TDGWTSessionExpiredException) {
-							eventBus.fireEvent(new SessionExpiredEvent(
-									SessionExpiredType.EXPIREDONSERVER));
-						} else {
-							Log.error("Error with uri resolver: "
-									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error",
-									"Error retrieving uri from resolver: "
-											+ caught.getLocalizedMessage());
+		if (internalURITD.getId() != null
+				&& !internalURITD.getId().isEmpty()
+				&& (internalURITD.getId().startsWith("http:") || internalURITD
+						.getId().startsWith("https:"))) {
+			Log.debug("Use direct link: " + internalURITD.getId());
+			chartLink = internalURITD.getId();
+			createChartImageResource();
+		} else {
+
+			UriResolverSession uriResolverSession = new UriResolverSession(
+					internalURITD.getId(), ApplicationType.SMP_ID, name,
+					internalURITD.getMimeType());
+			Log.debug("UriResolverSession: " + uriResolverSession);
+			TDGWTServiceAsync.INSTANCE.getUriFromResolver(uriResolverSession,
+					new AsyncCallback<String>() {
+
+						public void onFailure(Throwable caught) {
+							if (caught instanceof TDGWTSessionExpiredException) {
+								eventBus.fireEvent(new SessionExpiredEvent(
+										SessionExpiredType.EXPIREDONSERVER));
+							} else {
+								Log.error("Error with uri resolver: "
+										+ caught.getLocalizedMessage());
+								UtilsGXT3.alert(
+										msgsCommon.error(),
+										msgs.errorRetrievingUriFromResolverFixed()
+												+ caught.getLocalizedMessage());
+							}
 						}
-					}
 
-					public void onSuccess(String link) {
-						Log.debug("Retrieved link: " + link);
-						chartLink = link;
-						createChartImageResource();
-					}
-
-				});
+						public void onSuccess(String link) {
+							Log.debug("Retrieved link: " + link);
+							chartLink = link;
+							createChartImageResource();
+						}
 
+					});
+		}
 	}
 
 	protected void createChartImageResource() {
 
-		/*final String path = GWT.getModuleBaseURL()
-				+ RETRIEVE_FILE_AND_DISCOVER_MIME_TYPE_SERVLET;*/
+		/*
+		 * final String path = GWT.getModuleBaseURL() +
+		 * RETRIEVE_FILE_AND_DISCOVER_MIME_TYPE_SERVLET;
+		 */
 
 		chartImageResource = new ImageResource() {
 
@@ -316,7 +338,7 @@ public class ChartViewerPanel extends FramedPanel {
 		btnZoomIn = new ToggleButton();
 		btnZoomIn.setValue(false);
 		btnZoomIn.setIcon(ResourceBundle.INSTANCE.magnifierZoomIn());
-		btnZoomIn.setToolTip("Zoom In");
+		btnZoomIn.setToolTip(msgs.btnZoomInToolTip());
 		btnZoomIn.addSelectHandler(new SelectHandler() {
 
 			@Override
@@ -331,7 +353,7 @@ public class ChartViewerPanel extends FramedPanel {
 		btnZoomOut = new ToggleButton();
 		btnZoomOut.setValue(false);
 		btnZoomOut.setIcon(ResourceBundle.INSTANCE.magnifierZoomOut());
-		btnZoomOut.setToolTip("Zoom Out");
+		btnZoomOut.setToolTip(msgs.btnZoomOutToolTip());
 		btnZoomOut.addSelectHandler(new SelectHandler() {
 
 			@Override
@@ -346,7 +368,7 @@ public class ChartViewerPanel extends FramedPanel {
 		btnMove = new ToggleButton();
 		btnMove.setValue(false);
 		btnMove.setIcon(ResourceBundle.INSTANCE.move());
-		btnMove.setToolTip("Move");
+		btnMove.setToolTip(msgs.btnMoveToolTip());
 		btnMove.addSelectHandler(new SelectHandler() {
 
 			@Override
@@ -402,7 +424,7 @@ public class ChartViewerPanel extends FramedPanel {
 
 		addHandlersForComboZoomLevel(props.label());
 
-		comboZoomLevel.setEmptyText("Zoom Level");
+		comboZoomLevel.setEmptyText(msgs.comboZoomLevelEmptyText());
 		comboZoomLevel.setItemId("ComboZoomLevel");
 		comboZoomLevel.setWidth(COMBO_ZOOM_LEVEL_WIDTH);
 		comboZoomLevel.setEditable(false);
@@ -412,7 +434,7 @@ public class ChartViewerPanel extends FramedPanel {
 		//
 		btnOpenInWindow = new TextButton();
 		btnOpenInWindow.setIcon(ResourceBundle.INSTANCE.application());
-		btnOpenInWindow.setToolTip("Open in new window");
+		btnOpenInWindow.setToolTip(msgs.btnOpenInWindowToolTip());
 		btnOpenInWindow.addSelectHandler(new SelectHandler() {
 
 			@Override
